Struct XwaylandShellV1
pub struct XwaylandShellV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
context object for Xwayland shell
xwayland_shell_v1 is a singleton global object that provides the ability to create a xwayland_surface_v1 object for a given wl_surface.
This interface is intended to be bound by the Xwayland server.
A compositor must not allow clients other than Xwayland to bind to this interface. A compositor should hide this global from other clients’ wl_registry. A client the compositor does not consider to be an Xwayland server attempting to bind this interface will result in an implementation-defined error.
An Xwayland server that has bound this interface must not
set the WL_SURFACE_ID atom on a window.
See also the Request enum for this interface.